[llvm] 6ee79e9 - [UpdateTestChecks] As part of using inclusive language within the

Eric Christopher via llvm-commits llvm-commits at lists.llvm.org
Fri Jun 19 21:35:28 PDT 2020


Author: Eric Christopher
Date: 2020-06-19T21:35:11-07:00
New Revision: 6ee79e9b921f8e8d240e2ccc75e4740d97392026

URL: https://github.com/llvm/llvm-project/commit/6ee79e9b921f8e8d240e2ccc75e4740d97392026
DIFF: https://github.com/llvm/llvm-project/commit/6ee79e9b921f8e8d240e2ccc75e4740d97392026.diff

LOG: [UpdateTestChecks] As part of using inclusive language within the
llvm project, migrate away from the use of blacklist and whitelist.

Added: 
    

Modified: 
    llvm/utils/UpdateTestChecks/common.py

Removed: 
    


################################################################################
diff  --git a/llvm/utils/UpdateTestChecks/common.py b/llvm/utils/UpdateTestChecks/common.py
index d8a646853faa..9abb8d790c5f 100644
--- a/llvm/utils/UpdateTestChecks/common.py
+++ b/llvm/utils/UpdateTestChecks/common.py
@@ -273,8 +273,8 @@ def transform_line_vars(match):
 
 
 def add_checks(output_lines, comment_marker, prefix_list, func_dict, func_name, check_label_format, is_asm, is_analyze):
-  # prefix_blacklist are prefixes we cannot use to print the function because it doesn't exist in run lines that use these prefixes as well.
-  prefix_blacklist = set()
+  # prefix_exclusions are prefixes we cannot use to print the function because it doesn't exist in run lines that use these prefixes as well.
+  prefix_exclusions = set()
   printed_prefixes = []
   for p in prefix_list:
     checkprefixes = p[0]
@@ -282,18 +282,18 @@ def add_checks(output_lines, comment_marker, prefix_list, func_dict, func_name,
     # exist for this run line. A subset of the check prefixes might know about the function but only because
     # other run lines created it.
     if any(map(lambda checkprefix: func_name not in func_dict[checkprefix], checkprefixes)):
-        prefix_blacklist |= set(checkprefixes)
+        prefix_exclusions |= set(checkprefixes)
         continue
 
   # prefix_blacklist is constructed, we can now emit the output
   for p in prefix_list:
     checkprefixes = p[0]
     for checkprefix in checkprefixes:
       if checkprefix in printed_prefixes:
         break
 
-      # Check if the prefix is blacklisted.
-      if checkprefix in prefix_blacklist:
+      # Check if the prefix is excluded.
+      if checkprefix in prefix_exclusions:
         continue
 
       # If we do not have output for this prefix we skip it.
@@ -282,18 +282,18 @@ def add_checks(output_lines, comment_marker, prefix_list, func_dict, func_name,
         continue
 
-  # prefix_blacklist is constructed, we can now emit the output
+  # prefix_exclusions is constructed, we can now emit the output
   for p in prefix_list:
     checkprefixes = p[0]


        


More information about the llvm-commits mailing list